//
//  FlipViewTutorialViewController.m
//  FlipViewTutorial
//
//  Created by Rubén García Pérez on 30/08/11.
//  Copyright 2011 rugarciap.com. All rights reserved.
//

#import "FlipViewTutorialViewController.h"

#import "FlipViewOneController.h"
#import "FlipViewTwoController.h"

@implementation FlipViewTutorialViewController

@synthesize flipViewOneController, flipViewTwoController;

- (void) flipViews {
    
    // disable user interaction during the flip
    self.view.userInteractionEnabled = NO;
    
    // setup the animation group and creates it
    [UIView beginAnimations:nil context:nil];
    [UIView setAnimationDuration:0.75];
    [UIView setAnimationDelegate:self];
    [UIView setAnimationDidStopSelector:@selector(flipViewsAnimationStop:finished:context:)];
    
    if (viewOneVisible){
            
        // If view one is visible, hides it and add the new one with the "Flip" style transition
        [UIView setAnimationTransition:UIViewAnimationTransitionFlipFromRight forView:self.view cache:YES];
        [self.flipViewOneController.view removeFromSuperview];        
        [self.view addSubview:flipViewTwoController.view];

    } else {
        
        // If the view two is visible, hides it and display the one with the "Flip" transition.
        [UIView setAnimationTransition:UIViewAnimationTransitionFlipFromLeft forView:self.view cache:YES];        
        [self.view addSubview:self.flipViewOneController.view];
        [self.flipViewTwoController.view removeFromSuperview];     
        
    }
    
    // Commit animations to show the effect
    [UIView commitAnimations];
    
    // Register the current visible view
    viewOneVisible = !viewOneVisible;    
}


- (void)flipViewsAnimationStop:(NSString *)animationID finished:(NSNumber *)finished context:(void *)context {
    self.view.userInteractionEnabled = YES;
}


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    [super viewDidLoad];
        
    // Creates the instance of each controller
    self.flipViewOneController = [[FlipViewOneController alloc] initWithNibName:@"FlipViewOneController" bundle:[NSBundle mainBundle]];    
    self.flipViewTwoController = [[FlipViewTwoController alloc] initWithNibName:@"FlipViewTwoController" bundle:[NSBundle mainBundle]];
    
    // Assign the  controller instance
    self.flipViewOneController.controller = self;
    self.flipViewTwoController.controller = self;
    
    // Load and show the view one by default
    viewOneVisible = YES;
    [self.view addSubview:self.flipViewOneController.view];
    
}

- (void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event {
    [self flipViews];
}

- (void) dealloc {
    
    [super dealloc];
    [self.flipViewOneController release];
    [self.flipViewTwoController release];

}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}


- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}




@end
